@@ -44,7 +44,7 @@ void distro_cd_detected(UpgradeNotifier *un, char *mount_point)
    switch(res) {
    case RES_START_PM:
       cmd = g_strdup_printf("synaptic --add-cdrom %s",mount_point);
-      invoke_with_gksu(cmd, _("Package manager"));
+      invoke_with_gksu(cmd, "/usr/share/applications/synaptic.desktop");
       break;
    }
    gtk_widget_destroy (dialog);
