@@ -533,8 +533,10 @@ gboolean check_update_hooks(TrayApplet *ta)
    const gchar *hook_file;
 
    dir=g_dir_open(HOOKS_DIR, 0, NULL);
-   if(dir == NULL)
+   if(dir == NULL) {
       g_warning("can't read %s directory\n",HOOKS_DIR);
+      return FALSE;
+   }
 
    g_debug("reading '%s' dir", HOOKS_DIR);
    int unseen_count = 0;
