@@ -46,10 +46,6 @@ extern gboolean up_get_clipboard (void);
 gboolean update_timer_finished(gpointer data);
 static void tray_destroyed_cb(GtkWidget *widget, void *data);
 
-#define UPDATE_ICON_FILE PACKAGE_DATA_DIR"/pixmaps/update-icon.png"
-#define HOOK_ICON_FILE PACKAGE_DATA_DIR"/pixmaps/hook-notifier.png"
-#define REBOOT_ICON_FILE PACKAGE_DATA_DIR"/pixmaps/reboot-icon.png"
-
 // the time when we check for fam events
 #define TIMEOUT_FAM 1000*5 /* 5 sec */
 
@@ -79,11 +75,13 @@ invoke_with_gksu(gchar *cmd, gchar *desktop)
 
 
 gboolean
-trayapplet_create (TrayApplet *un, char *name, char *iconfile)
+trayapplet_create (TrayApplet *un, char *name)
 {
         //g_print("trayicon_create()\n");
 	GdkPixbuf *pixbuf;
 
+	GtkIconTheme* icon_theme = gtk_icon_theme_get_default();
+
 	/* setup widgets */
         un->tooltip = gtk_tooltips_new ();
 	un->tray_icon = egg_tray_icon_new (name);
@@ -96,7 +94,8 @@ trayapplet_create (TrayApplet *un, char *name, char *iconfile)
 	pixbuf = gtk_image_get_pixbuf (GTK_IMAGE(un->icon));
 	if (pixbuf)
 		g_object_unref (G_OBJECT (pixbuf));
-	pixbuf = gdk_pixbuf_new_from_file (iconfile, NULL);
+	pixbuf = gtk_icon_theme_load_icon (icon_theme, name,
+					   16, 0,NULL);
 	gtk_image_set_from_pixbuf (GTK_IMAGE (un->icon), pixbuf);
 
 	/* build container */
@@ -156,6 +155,11 @@ monitor_cb(GnomeVFSMonitorHandle *handle,
       //g_print("new hook!\n");
       un->hook_pending = TRUE;
    }
+   if(strstr(info_uri, CRASHREPORT_DIR)) {
+      //g_print("crashreport found\n");
+      un->crashreport_pending = TRUE;
+   }
+
 }
 
 /*
@@ -166,6 +170,7 @@ monitor_cb(GnomeVFSMonitorHandle *handle,
  *                   lists-dir, archive-cache, or /var/lib/dpkg/status
  * - hook_pending: we have new upgrade hoook information
  * - reboot_pending: we need to reboot
+ * - crashreport_pending: we have a new crashreport
  *
  */
 gboolean file_monitor_periodic_check(gpointer data)
@@ -226,6 +231,12 @@ gboolean file_monitor_periodic_check(gpointer data)
       un->last_apt_action = 0;
    }
 
+   if(un->crashreport_pending) {
+      g_print("checking for valid crashreport now\n");
+      crashreport_check (un->crashreport);
+      un->crashreport_pending = FALSE;
+   }
+
    // reset the bitfields (for the next "time-slice")
    un->dpkg_was_run = FALSE;
    un->apt_get_runing = FALSE;
@@ -256,33 +267,32 @@ gboolean monitor_init(UpgradeNotifier *un)
    GnomeVFSResult res;
    GnomeVFSMonitorHandle *monitor_handle;
 
+   // monitor thise dirs
    static const char *monitor_dirs[] = { 
       "/var/lib/apt/lists/", "/var/lib/apt/list/partial", 
       "/var/cache/apt/archives/", "/var/cache/apt/archives/partial", 
-      HOOKS_DIR,
+      HOOKS_DIR, 
+      CRASHREPORT_DIR,
       NULL};
-      
    for(i=0;monitor_dirs[i] != NULL;i++) {
       res = gnome_vfs_monitor_add(&monitor_handle,
 				  monitor_dirs[i],
 				  GNOME_VFS_MONITOR_DIRECTORY,
 				  monitor_cb, un);
    }
-   res = gnome_vfs_monitor_add(&monitor_handle,
-			       "/var/lib/dpkg/status", 
-			       GNOME_VFS_MONITOR_FILE,
-			       monitor_cb,
-			       un);
-   res = gnome_vfs_monitor_add(&monitor_handle,
-			       "/var/lib/update-notifier/dpkg-run-stamp", 
-			       GNOME_VFS_MONITOR_FILE,
-			       monitor_cb,
-			       un);
-   res = gnome_vfs_monitor_add(&monitor_handle,
-			       "/var/run/reboot-required", 
-			       GNOME_VFS_MONITOR_FILE,
-			       monitor_cb,
-			       un);
+
+   // and those files
+   static const char *monitor_files[] = { 
+      "/var/lib/dpkg/status", 
+      "/var/lib/update-notifier/dpkg-run-stamp", 
+      REBOOT_FILE,
+      NULL};
+   for(i=0;monitor_files[i] != NULL;i++) {
+      res = gnome_vfs_monitor_add(&monitor_handle,
+				  monitor_files[i],
+				  GNOME_VFS_MONITOR_FILE,
+				  monitor_cb, un);
+   }
 
    g_timeout_add (TIMEOUT_FAM, (GSourceFunc)file_monitor_periodic_check, un);
 
@@ -300,7 +310,8 @@ tray_icons_init(UpgradeNotifier *un)
 
    /* new upates tray icon */
    un->update = g_new0 (TrayApplet, 1);
-   trayapplet_create(un->update, "update-notifier", UPDATE_ICON_FILE);
+
+   trayapplet_create(un->update, "updates-notifier");
    update_tray_icon_init(un->update);
 
    /* a destroy signal handler (e.g. when the gnome-panel is restarted */
@@ -309,14 +320,19 @@ tray_icons_init(UpgradeNotifier *un)
 
    /* update hook icon*/
    un->hook = g_new0 (TrayApplet, 1);
-   trayapplet_create(un->hook, "hook-notifier", HOOK_ICON_FILE);
+   trayapplet_create(un->hook, "hook-notifier");
    hook_tray_icon_init(un->hook);
 
    /* reboot required icon */
    un->reboot = g_new0 (TrayApplet, 1);
-   trayapplet_create(un->reboot, "reboot-notifier", REBOOT_ICON_FILE);
+   trayapplet_create(un->reboot, "reboot-notifier");
    reboot_tray_icon_init(un->reboot);
 
+   /* crashreport detected icon */
+   un->crashreport = g_new0 (TrayApplet, 1);
+   trayapplet_create(un->crashreport, "crashreport-notifier");
+   crashreport_tray_icon_init(un->crashreport);
+
    return FALSE; // for the tray_destroyed_cb
 }
 
@@ -388,6 +404,9 @@ main (int argc, char *argv[])
         bind_textdomain_codeset(PACKAGE, "UTF-8");
         textdomain(PACKAGE);
 
+	g_set_application_name (_("update-notifier"));
+	gtk_window_set_default_icon_name ("update-notifier");
+
 	//g_print("starting update-notifier\n");
 	
 	// check if we should run at all (see HideAdminTools spec
