@@ -30,6 +30,9 @@
 #define GCONF_KEY_NO_UPDATE_NOTIFICATIONS "/apps/update-notifier/no_show_notifications"
 
 #define HOOKS_DIR "/var/lib/update-notifier/user.d/"
+#define CRASHREPORT_HELPER "/usr/share/apport/apport-checkreports"
+#define CRASHREPORT_REPORT_APP "/usr/share/apport/apport-gtk"
+#define CRASHREPORT_DIR "/var/crash/"
 #define REBOOT_FILE "/var/run/reboot-required"
 
 void invoke_with_gksu(gchar *cmd, gchar *descr);
@@ -53,6 +56,7 @@ struct _UpgradeNotifier
    TrayApplet *update;
    TrayApplet *reboot;
    TrayApplet *hook;
+   TrayApplet *crashreport;
 
    GConfClient *gconf;
 
@@ -67,6 +71,7 @@ struct _UpgradeNotifier
    // these field are "global" (time-wise)
    gboolean reboot_pending;
    gboolean hook_pending;
+   gboolean crashreport_pending;
    time_t last_apt_action;
 
 };
