@@ -42,9 +42,10 @@ button_release_cb (GtkWidget *widget,
 	 priv->active_notification = NULL;
       }
 
-      index = gconf_client_get_int(priv->gconf,
-				   GCONF_KEY_DEFAULT_ACTION, 
-				   NULL);
+/*       index = gconf_client_get_int(priv->gconf, */
+/* 				   GCONF_KEY_DEFAULT_ACTION,  */
+/* 				   NULL); */
+      index = 0;
       //g_print("%s %s\n",actions[index][0],actions[index][1]);
 
       // work around double clicking people by delaying clicks for 2
